@@ -1,6 +1,7 @@
 import {NgModule} from '@angular/core';
 import {RouterModule, Routes} from '@angular/router';
 import {MarkItemMissingPiecesComponent} from './missing-pieces.component';
+import {CopyAlertsPageComponent} from '@eg/staff/share/holdings/copy-alerts-page.component';
 
 const routes: Routes = [{
     path: 'missing_pieces',
@@ -8,6 +9,9 @@ const routes: Routes = [{
 }, {
     path: 'missing_pieces/:id',
     component: MarkItemMissingPiecesComponent
+}, {
+    path: 'alerts',
+    component: CopyAlertsPageComponent
 }];
 
 @NgModule({
