@@ -173,6 +173,8 @@ export class ImportComponent implements OnInit, AfterViewInit, OnDestroy {
         this.recordType = 'bib';
         this.bibTrashGroups = [];
         this.formTemplates = {};
+        this.backgroundImportEmail = this.auth.user().email();
+        console.debug('user email is:', this.auth.user().email());
 
         if (this.vandelay.importSelection) {
             // Apply start-id values to our comboboxes based on our
@@ -323,7 +325,8 @@ export class ImportComponent implements OnInit, AfterViewInit, OnDestroy {
                 break;
 
             case 'matchSets':
-                list = this.vandelay.matchSets[rtype];
+                const matchSetType = rtype === 'bib-acq' ? 'bib' : rtype;
+                list = this.vandelay.matchSets[matchSetType];
                 break;
 
             case 'importItemDefs':
