@@ -20,6 +20,7 @@ export class StaffMFAComponent implements OnInit {
     active_factor = 'CONFIG';
     method_suffix = '';
     totp_uri = '';
+    totp_uri_parts = {};
     provisional = false;
     required_for_token = true;
     allowed_for_token = true;
@@ -168,6 +169,27 @@ export class StaffMFAComponent implements OnInit {
         }
     }
 
+    parse_totp_uri_parts(): any {
+        const path = this.totp_uri.split('?')[0];
+
+        // eslint-disable-next-line no-magic-numbers
+        const who = path.split('/')[3]; // 3 isn't a magic number here, any more than 0 above, or 1 below. whatevs.
+
+        this.totp_uri_parts = {
+            type         : path.split('/')[2],
+            issuer_label : decodeURIComponent(who.split(':')[0]),
+            account      : decodeURIComponent(who.split(':')[1]),
+        };
+
+        this.totp_uri // split up the cgi params
+            .split('?')[1]
+            .split('&')
+            .forEach( p => {
+                const x = p.split('=');
+                this.totp_uri_parts[x[0]] = decodeURIComponent(x[1]);
+            });
+    }
+
     initFactorSetup(factor: string, data?: any) {
         this.net.request(
             'open-ils.auth_mfa',
@@ -177,6 +199,10 @@ export class StaffMFAComponent implements OnInit {
             if (res) {
                 if (factor === 'totp') {
                     this.totp_uri = res.uri;
+                    /* Angular's DefaultUrlSerializer is crap and returns an empty UrlTree for otpauth URIs */
+                    // const parser = new DefaultUrlSerializer();
+                    // this.parsed_totp_uri = parser.parse(this.totp_uri);
+                    this.parse_totp_uri_parts();
                 } else if (factor === 'email') {
                     this.email_otp_addr = res.email;
                     this.email_otp_sent = !!res.sent;
@@ -250,6 +276,7 @@ export class StaffMFAComponent implements OnInit {
             if (res) {
                 if (factor === 'totp') {
                     this.totp_uri = '';
+                    this.totp_uri_parts = {};
                 } else if (factor === 'email') {
                     this.email_otp_addr = '';
                     this.email_otp_sent = false;
@@ -273,6 +300,7 @@ export class StaffMFAComponent implements OnInit {
             if (res) {
                 if (factor === 'totp') {
                     this.totp_uri = '';
+                    this.totp_uri_parts = {};
                 } else if (factor === 'email') {
                     this.email_otp_sent = false;
                 } else if (factor === 'sms') {
@@ -361,6 +389,7 @@ export class StaffMFAComponent implements OnInit {
                 console.debug(`factor ${factor} initialized for removal`);
                 if (factor === 'totp') {
                     this.totp_uri = '';
+                    this.totp_uri_parts = {};
                 } else if (factor === 'email') {
                     this.email_otp_sent = true;
                 } else if (factor === 'sms') {
