@@ -328,7 +328,7 @@ sub init_ro_object_cache {
                 $cache{i18ns}{$locale}{$string_id} = $string_obj->string;
             };
             if ($@) {
-                my $err = shift;
+                my $err = shift; # XXX This is wrong, probably left over from try/catch. Should be `my $err = $@;`
                 $logger->warn("get_i18n_string{$locale}{$string_id}, err = $err");
             }
             $cache{i18ns}{$locale}{$string_id} ||= $fallback_string || 'XXX';
@@ -490,7 +490,8 @@ sub get_records_and_facets {
         $unapi_args->{site},
         $unapi_args->{depth},
         $unapi_args->{flesh_depth},
-        ($unapi_args->{pref_lib} || '')
+        ($unapi_args->{pref_lib} || ''),
+        ($unapi_args->{library_group} || '')
     );
 
     my %tmp_data;
@@ -537,7 +538,8 @@ sub get_records_and_facets {
                 $unapi_args->{depth}, 
                 $slimit,
                 undef, undef, undef, undef, undef, undef, undef, undef,
-                $unapi_args->{pref_lib}
+                $unapi_args->{pref_lib},
+                $unapi_args->{library_group}
             ]}
         );
     
@@ -982,6 +984,8 @@ sub load_org_util_funcs {
     $ctx->{org_within_scope} = sub {
         my ($ctx_ou, $test_ou, $depth) = @_;
 
+        return 1 if !$ctx_ou or !$test_ou; # bad input, we'll just show it
+
         return 1 if $ctx_ou->id == $test_ou->id;
 
         if ($depth) {
